@@ -1,5 +1,7 @@
 """
-Main interface for datasync service literal definitions.
+Type annotations for datasync service literal definitions.
+
+[Open documentation](./literals.md)
 
 Usage::
 
