@@ -1,5 +1,7 @@
 """
-Main interface for datasync service client paginators.
+Type annotations for datasync service client paginators.
+
+[Open documentation](./paginators.md)
 
 Usage::
 
@@ -28,7 +30,7 @@ from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_datasync.type_defs import (
+from .type_defs import (
     ListAgentsResponseTypeDef,
     ListLocationsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
@@ -50,20 +52,21 @@ __all__ = (
 
 class ListAgentsPaginator(Boto3Paginator):
     """
-    [Paginator.ListAgents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListAgents)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListAgents)[Show boto3-stubs documentation](./paginators.md#listagentspaginator)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListAgentsResponseTypeDef]:
         """
-        [ListAgents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListAgents.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListAgents.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listagentspaginator)
         """
 
 
 class ListLocationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListLocations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListLocations)[Show boto3-stubs documentation](./paginators.md#listlocationspaginator)
     """
 
     def paginate(
@@ -72,39 +75,42 @@ class ListLocationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListLocationsResponseTypeDef]:
         """
-        [ListLocations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListLocations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListLocations.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listlocationspaginator)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)[Show boto3-stubs documentation](./paginators.md#listtagsforresourcepaginator)
     """
 
     def paginate(
         self, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTagsForResourceResponseTypeDef]:
         """
-        [ListTagsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listtagsforresourcepaginator)
         """
 
 
 class ListTaskExecutionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListTaskExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)[Show boto3-stubs documentation](./paginators.md#listtaskexecutionspaginator)
     """
 
     def paginate(
         self, TaskArn: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTaskExecutionsResponseTypeDef]:
         """
-        [ListTaskExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listtaskexecutionspaginator)
         """
 
 
 class ListTasksPaginator(Boto3Paginator):
     """
-    [Paginator.ListTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListTasks)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListTasks)[Show boto3-stubs documentation](./paginators.md#listtaskspaginator)
     """
 
     def paginate(
@@ -113,5 +119,6 @@ class ListTasksPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListTasksResponseTypeDef]:
         """
-        [ListTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListTasks.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/datasync.html#DataSync.Paginator.ListTasks.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listtaskspaginator)
         """
