@@ -1,5 +1,7 @@
 """
-Main interface for datasync service type definitions.
+Type annotations for datasync service type definitions.
+
+[Open documentation](./type_defs.md)
 
 Usage::
 
@@ -13,11 +15,10 @@ import sys
 from datetime import datetime
 from typing import List
 
-from mypy_boto3_datasync.literals import (
+from .literals import (
     AgentStatus,
     Atime,
     EndpointType,
-    FilterType,
     Gid,
     LocationFilterName,
     LogLevel,
@@ -41,6 +42,10 @@ from mypy_boto3_datasync.literals import (
     VerifyMode,
 )
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -49,20 +54,6 @@ else:
 
 __all__ = (
     "AgentListEntryTypeDef",
-    "Ec2ConfigTypeDef",
-    "FilterRuleTypeDef",
-    "LocationListEntryTypeDef",
-    "NfsMountOptionsTypeDef",
-    "OnPremConfigTypeDef",
-    "OptionsTypeDef",
-    "PrivateLinkConfigTypeDef",
-    "S3ConfigTypeDef",
-    "SmbMountOptionsTypeDef",
-    "TagListEntryTypeDef",
-    "TaskExecutionListEntryTypeDef",
-    "TaskExecutionResultDetailTypeDef",
-    "TaskListEntryTypeDef",
-    "TaskScheduleTypeDef",
     "CreateAgentResponseTypeDef",
     "CreateLocationEfsResponseTypeDef",
     "CreateLocationFsxWindowsResponseTypeDef",
@@ -80,135 +71,104 @@ __all__ = (
     "DescribeLocationSmbResponseTypeDef",
     "DescribeTaskExecutionResponseTypeDef",
     "DescribeTaskResponseTypeDef",
+    "Ec2ConfigTypeDef",
+    "FilterRuleTypeDef",
     "ListAgentsResponseTypeDef",
     "ListLocationsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "ListTaskExecutionsResponseTypeDef",
     "ListTasksResponseTypeDef",
     "LocationFilterTypeDef",
+    "LocationListEntryTypeDef",
+    "NfsMountOptionsTypeDef",
+    "OnPremConfigTypeDef",
+    "OptionsTypeDef",
     "PaginatorConfigTypeDef",
+    "PrivateLinkConfigTypeDef",
+    "S3ConfigTypeDef",
+    "SmbMountOptionsTypeDef",
     "StartTaskExecutionResponseTypeDef",
+    "TagListEntryTypeDef",
+    "TaskExecutionListEntryTypeDef",
+    "TaskExecutionResultDetailTypeDef",
     "TaskFilterTypeDef",
+    "TaskListEntryTypeDef",
+    "TaskScheduleTypeDef",
 )
 
 AgentListEntryTypeDef = TypedDict(
-    "AgentListEntryTypeDef", {"AgentArn": str, "Name": str, "Status": AgentStatus}, total=False
-)
-
-Ec2ConfigTypeDef = TypedDict("Ec2ConfigTypeDef", {"SubnetArn": str, "SecurityGroupArns": List[str]})
-
-FilterRuleTypeDef = TypedDict(
-    "FilterRuleTypeDef", {"FilterType": FilterType, "Value": str}, total=False
-)
-
-LocationListEntryTypeDef = TypedDict(
-    "LocationListEntryTypeDef", {"LocationArn": str, "LocationUri": str}, total=False
-)
-
-NfsMountOptionsTypeDef = TypedDict("NfsMountOptionsTypeDef", {"Version": NfsVersion}, total=False)
-
-OnPremConfigTypeDef = TypedDict("OnPremConfigTypeDef", {"AgentArns": List[str]})
-
-OptionsTypeDef = TypedDict(
-    "OptionsTypeDef",
+    "AgentListEntryTypeDef",
     {
-        "VerifyMode": VerifyMode,
-        "OverwriteMode": OverwriteMode,
-        "Atime": Atime,
-        "Mtime": Mtime,
-        "Uid": Uid,
-        "Gid": Gid,
-        "PreserveDeletedFiles": PreserveDeletedFiles,
-        "PreserveDevices": PreserveDevices,
-        "PosixPermissions": PosixPermissions,
-        "BytesPerSecond": int,
-        "TaskQueueing": TaskQueueing,
-        "LogLevel": LogLevel,
-        "TransferMode": TransferMode,
+        "AgentArn": str,
+        "Name": str,
+        "Status": AgentStatus,
     },
     total=False,
 )
 
-PrivateLinkConfigTypeDef = TypedDict(
-    "PrivateLinkConfigTypeDef",
+CreateAgentResponseTypeDef = TypedDict(
+    "CreateAgentResponseTypeDef",
     {
-        "VpcEndpointId": str,
-        "PrivateLinkEndpoint": str,
-        "SubnetArns": List[str],
-        "SecurityGroupArns": List[str],
+        "AgentArn": str,
     },
     total=False,
 )
 
-S3ConfigTypeDef = TypedDict("S3ConfigTypeDef", {"BucketAccessRoleArn": str})
-
-SmbMountOptionsTypeDef = TypedDict("SmbMountOptionsTypeDef", {"Version": SmbVersion}, total=False)
-
-_RequiredTagListEntryTypeDef = TypedDict("_RequiredTagListEntryTypeDef", {"Key": str})
-_OptionalTagListEntryTypeDef = TypedDict(
-    "_OptionalTagListEntryTypeDef", {"Value": str}, total=False
-)
-
-
-class TagListEntryTypeDef(_RequiredTagListEntryTypeDef, _OptionalTagListEntryTypeDef):
-    pass
-
-
-TaskExecutionListEntryTypeDef = TypedDict(
-    "TaskExecutionListEntryTypeDef",
-    {"TaskExecutionArn": str, "Status": TaskExecutionStatus},
-    total=False,
-)
-
-TaskExecutionResultDetailTypeDef = TypedDict(
-    "TaskExecutionResultDetailTypeDef",
-    {
-        "PrepareDuration": int,
-        "PrepareStatus": PhaseStatus,
-        "TotalDuration": int,
-        "TransferDuration": int,
-        "TransferStatus": PhaseStatus,
-        "VerifyDuration": int,
-        "VerifyStatus": PhaseStatus,
-        "ErrorCode": str,
-        "ErrorDetail": str,
-    },
-    total=False,
-)
-
-TaskListEntryTypeDef = TypedDict(
-    "TaskListEntryTypeDef", {"TaskArn": str, "Status": TaskStatus, "Name": str}, total=False
-)
-
-TaskScheduleTypeDef = TypedDict("TaskScheduleTypeDef", {"ScheduleExpression": str})
-
-CreateAgentResponseTypeDef = TypedDict("CreateAgentResponseTypeDef", {"AgentArn": str}, total=False)
-
 CreateLocationEfsResponseTypeDef = TypedDict(
-    "CreateLocationEfsResponseTypeDef", {"LocationArn": str}, total=False
+    "CreateLocationEfsResponseTypeDef",
+    {
+        "LocationArn": str,
+    },
+    total=False,
 )
 
 CreateLocationFsxWindowsResponseTypeDef = TypedDict(
-    "CreateLocationFsxWindowsResponseTypeDef", {"LocationArn": str}, total=False
+    "CreateLocationFsxWindowsResponseTypeDef",
+    {
+        "LocationArn": str,
+    },
+    total=False,
 )
 
 CreateLocationNfsResponseTypeDef = TypedDict(
-    "CreateLocationNfsResponseTypeDef", {"LocationArn": str}, total=False
+    "CreateLocationNfsResponseTypeDef",
+    {
+        "LocationArn": str,
+    },
+    total=False,
 )
 
 CreateLocationObjectStorageResponseTypeDef = TypedDict(
-    "CreateLocationObjectStorageResponseTypeDef", {"LocationArn": str}, total=False
+    "CreateLocationObjectStorageResponseTypeDef",
+    {
+        "LocationArn": str,
+    },
+    total=False,
 )
 
 CreateLocationS3ResponseTypeDef = TypedDict(
-    "CreateLocationS3ResponseTypeDef", {"LocationArn": str}, total=False
+    "CreateLocationS3ResponseTypeDef",
+    {
+        "LocationArn": str,
+    },
+    total=False,
 )
 
 CreateLocationSmbResponseTypeDef = TypedDict(
-    "CreateLocationSmbResponseTypeDef", {"LocationArn": str}, total=False
+    "CreateLocationSmbResponseTypeDef",
+    {
+        "LocationArn": str,
+    },
+    total=False,
 )
 
-CreateTaskResponseTypeDef = TypedDict("CreateTaskResponseTypeDef", {"TaskArn": str}, total=False)
+CreateTaskResponseTypeDef = TypedDict(
+    "CreateTaskResponseTypeDef",
+    {
+        "TaskArn": str,
+    },
+    total=False,
+)
 
 DescribeAgentResponseTypeDef = TypedDict(
     "DescribeAgentResponseTypeDef",
@@ -342,48 +302,231 @@ DescribeTaskResponseTypeDef = TypedDict(
     total=False,
 )
 
+Ec2ConfigTypeDef = TypedDict(
+    "Ec2ConfigTypeDef",
+    {
+        "SubnetArn": str,
+        "SecurityGroupArns": List[str],
+    },
+)
+
+FilterRuleTypeDef = TypedDict(
+    "FilterRuleTypeDef",
+    {
+        "FilterType": Literal["SIMPLE_PATTERN"],
+        "Value": str,
+    },
+    total=False,
+)
+
 ListAgentsResponseTypeDef = TypedDict(
     "ListAgentsResponseTypeDef",
-    {"Agents": List["AgentListEntryTypeDef"], "NextToken": str},
+    {
+        "Agents": List["AgentListEntryTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
 ListLocationsResponseTypeDef = TypedDict(
     "ListLocationsResponseTypeDef",
-    {"Locations": List["LocationListEntryTypeDef"], "NextToken": str},
+    {
+        "Locations": List["LocationListEntryTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
-    {"Tags": List["TagListEntryTypeDef"], "NextToken": str},
+    {
+        "Tags": List["TagListEntryTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
 ListTaskExecutionsResponseTypeDef = TypedDict(
     "ListTaskExecutionsResponseTypeDef",
-    {"TaskExecutions": List["TaskExecutionListEntryTypeDef"], "NextToken": str},
+    {
+        "TaskExecutions": List["TaskExecutionListEntryTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
 ListTasksResponseTypeDef = TypedDict(
     "ListTasksResponseTypeDef",
-    {"Tasks": List["TaskListEntryTypeDef"], "NextToken": str},
+    {
+        "Tasks": List["TaskListEntryTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
 LocationFilterTypeDef = TypedDict(
-    "LocationFilterTypeDef", {"Name": LocationFilterName, "Values": List[str], "Operator": Operator}
+    "LocationFilterTypeDef",
+    {
+        "Name": LocationFilterName,
+        "Values": List[str],
+        "Operator": Operator,
+    },
+)
+
+LocationListEntryTypeDef = TypedDict(
+    "LocationListEntryTypeDef",
+    {
+        "LocationArn": str,
+        "LocationUri": str,
+    },
+    total=False,
+)
+
+NfsMountOptionsTypeDef = TypedDict(
+    "NfsMountOptionsTypeDef",
+    {
+        "Version": NfsVersion,
+    },
+    total=False,
+)
+
+OnPremConfigTypeDef = TypedDict(
+    "OnPremConfigTypeDef",
+    {
+        "AgentArns": List[str],
+    },
+)
+
+OptionsTypeDef = TypedDict(
+    "OptionsTypeDef",
+    {
+        "VerifyMode": VerifyMode,
+        "OverwriteMode": OverwriteMode,
+        "Atime": Atime,
+        "Mtime": Mtime,
+        "Uid": Uid,
+        "Gid": Gid,
+        "PreserveDeletedFiles": PreserveDeletedFiles,
+        "PreserveDevices": PreserveDevices,
+        "PosixPermissions": PosixPermissions,
+        "BytesPerSecond": int,
+        "TaskQueueing": TaskQueueing,
+        "LogLevel": LogLevel,
+        "TransferMode": TransferMode,
+    },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
+PrivateLinkConfigTypeDef = TypedDict(
+    "PrivateLinkConfigTypeDef",
+    {
+        "VpcEndpointId": str,
+        "PrivateLinkEndpoint": str,
+        "SubnetArns": List[str],
+        "SecurityGroupArns": List[str],
+    },
+    total=False,
+)
+
+S3ConfigTypeDef = TypedDict(
+    "S3ConfigTypeDef",
+    {
+        "BucketAccessRoleArn": str,
+    },
+)
+
+SmbMountOptionsTypeDef = TypedDict(
+    "SmbMountOptionsTypeDef",
+    {
+        "Version": SmbVersion,
+    },
+    total=False,
 )
 
 StartTaskExecutionResponseTypeDef = TypedDict(
-    "StartTaskExecutionResponseTypeDef", {"TaskExecutionArn": str}, total=False
+    "StartTaskExecutionResponseTypeDef",
+    {
+        "TaskExecutionArn": str,
+    },
+    total=False,
+)
+
+_RequiredTagListEntryTypeDef = TypedDict(
+    "_RequiredTagListEntryTypeDef",
+    {
+        "Key": str,
+    },
+)
+_OptionalTagListEntryTypeDef = TypedDict(
+    "_OptionalTagListEntryTypeDef",
+    {
+        "Value": str,
+    },
+    total=False,
+)
+
+
+class TagListEntryTypeDef(_RequiredTagListEntryTypeDef, _OptionalTagListEntryTypeDef):
+    pass
+
+
+TaskExecutionListEntryTypeDef = TypedDict(
+    "TaskExecutionListEntryTypeDef",
+    {
+        "TaskExecutionArn": str,
+        "Status": TaskExecutionStatus,
+    },
+    total=False,
+)
+
+TaskExecutionResultDetailTypeDef = TypedDict(
+    "TaskExecutionResultDetailTypeDef",
+    {
+        "PrepareDuration": int,
+        "PrepareStatus": PhaseStatus,
+        "TotalDuration": int,
+        "TransferDuration": int,
+        "TransferStatus": PhaseStatus,
+        "VerifyDuration": int,
+        "VerifyStatus": PhaseStatus,
+        "ErrorCode": str,
+        "ErrorDetail": str,
+    },
+    total=False,
 )
 
 TaskFilterTypeDef = TypedDict(
-    "TaskFilterTypeDef", {"Name": TaskFilterName, "Values": List[str], "Operator": Operator}
+    "TaskFilterTypeDef",
+    {
+        "Name": TaskFilterName,
+        "Values": List[str],
+        "Operator": Operator,
+    },
+)
+
+TaskListEntryTypeDef = TypedDict(
+    "TaskListEntryTypeDef",
+    {
+        "TaskArn": str,
+        "Status": TaskStatus,
+        "Name": str,
+    },
+    total=False,
+)
+
+TaskScheduleTypeDef = TypedDict(
+    "TaskScheduleTypeDef",
+    {
+        "ScheduleExpression": str,
+    },
 )
